@@ -101,8 +101,8 @@ def _convert_items_to_metis_tags(tags_dict: Optional[Attributes]):
 
 @log
 def setup(
-        service_name: str,
-        api_key: str,
+        service_name: Optional[str] = None,
+        api_key: Optional[str] = None,
         service_version: Optional[str] = None,
         resource_tags: Optional[Attributes] = None,
         plan_collection_option: Optional[PlanCollectType] = PlanCollectType.ESTIMATED,
@@ -194,9 +194,7 @@ class MetisInstrumentor(metaclass=SingletonMeta):
     def _set_exporters(self,
                        api_key: Optional[str] = None,
                        exporter_url: Optional[str] = "https://ingest.metisdata.io/"):
-        if bool(exporter_url) != bool(api_key):
-            raise ValueError("Endpoint and api_key must be provided")
-        if exporter_url is not None:
+        if api_key is not None and exporter_url is not None:
             self._add_processor(BatchSpanProcessor(MetisRemoteExporter(exporter_url, api_key, self.sentry_logger)))
 
         if strtobool(os.getenv("DEBUG", 'False')):
